==> koffice-2.1.0.tar.bz2: koffice-2.1.0/krita/image/tests/kis_bookmarked_configuration_manager_test.cpp <==
/*
 *  Copyright (c) 2007 Boudewijn Rempt boud@valdyas.org
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include "kis_bookmarked_configuration_manager_test.h"

#include <qtest_kde.h>
#include "kis_bookmarked_configuration_manager.h"
#include "kis_serializable_configuration.h"

class TestConfiguration : public KisSerializableConfiguration
{
public:

    using KisSerializableConfiguration::fromXML;
    using KisSerializableConfiguration::toXML;

    void fromXML(const QDomElement&) {
    }

    void toXML(QDomDocument&, QDomElement&) const {
    }
};

class TestConfigurationFactory : public KisSerializableConfigurationFactory
{
public:

    virtual KisSerializableConfiguration* createDefault() {
        return &tc;
    }

    virtual KisSerializableConfiguration* create(const QDomElement&) {
        return &tc;
    }
private:

    TestConfiguration tc;
};


void KisBookmarkedConfigurationManagerTest::testCreation()
{
    TestConfigurationFactory tcf;
    KisBookmarkedConfigurationManager test("Test", &tcf);
}


QTEST_KDEMAIN(KisBookmarkedConfigurationManagerTest, GUI)
#include "kis_bookmarked_configuration_manager_test.moc"

==> koffice-2.3.2.tar.bz2: koffice-2.3.2/krita/image/tests/kis_bookmarked_configuration_manager_test.cpp <==
/*
 *  Copyright (c) 2007 Boudewijn Rempt boud@valdyas.org
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include "kis_bookmarked_configuration_manager_test.h"

#include <qtest_kde.h>
#include "kis_bookmarked_configuration_manager.h"
#include "kis_serializable_configuration.h"

class TestConfiguration : public KisSerializableConfiguration
{
public:

    using KisSerializableConfiguration::fromXML;
    using KisSerializableConfiguration::toXML;

    void fromXML(const QDomElement&) {
    }

    void toXML(QDomDocument&, QDomElement&) const {
    }
};

class TestConfigurationFactory : public KisSerializableConfigurationFactory
{
public:

    virtual KisSerializableConfiguration* createDefault() {
        return &tc;
    }

    virtual KisSerializableConfiguration* create(const QDomElement&) {
        return &tc;
    }
private:

    TestConfiguration tc;
};


void KisBookmarkedConfigurationManagerTest::testCreation()
{
    TestConfigurationFactory *tcf = new TestConfigurationFactory;
    KisBookmarkedConfigurationManager test("Test", tcf);
}


QTEST_KDEMAIN(KisBookmarkedConfigurationManagerTest, GUI)
#include "kis_bookmarked_configuration_manager_test.moc"
